@@ -22,7 +22,8 @@ def main():
     def not_exists(row):
         table_name = row["table_name"]
         column_name = row["column_name"]
-        return ((table_name  == target["table_name"]).sum() + (column_name  == target["column_name"]).sum()) == 0
+
+        return ((table_name  == target["table_name"]).sum() * (column_name  == target["column_name"]).sum()) == 0
 
     print(f'Source schema has {len(source)} (table_name,column_name)')
     print(f'Target schema has {len(target)} (table_name,column_name)')
